<?php

use Uncanny_Automator\Recipe;


class Mailketing_Action
{
    use Recipe\Actions;

    public function __construct()
    {
        $this->setup_action();
    }

    /**
     *
     */

    protected function setup_action()
    {

        $this->set_integration('MAILKETING');
        $this->set_action_code('MAILEKTINGWEBHOOK');
        $this->set_action_meta('MLK');
        $this->set_requires_user(false);
        /* translators: Action - WordPress */
        $this->set_sentence(sprintf(esc_attr__('Add Subscriber to {{mailketing:%1$s}}  List', 'uncanny-automator'), $this->get_action_meta()));
        /* translators: Action - WordPress */
        $this->set_readable_sentence(esc_attr__('Add Subscriber to {{mailketing}} List', 'uncanny-automator'));
        $options_group = array(
    				$this->action_meta => $this->get_fields(),
          );

        $this->set_options_group($options_group);

        $this->register_action();
    }

    /**
     * @param int $user_id
     * @param array $action_data
     * @param int $recipe_id
     * @param array $args
     * @param $parsed
     */
    protected function process_action(int $user_id, array $action_data, int $recipe_id, array $args, $parsed)
    {
      $api_token=null;
        if (isset($action_data['meta']['list_id'])) {
          $optionsx = get_option( "mailketingsmtp_options" );
          $api_token   = $optionsx['mailketingsmtp_api'];
          $list_id=$action_data['meta']['list_id'];


        }


        if (!is_null($api_token)) {
          $merge_fields = $action_data['meta']['MERGE_FIELDS'];
    $fields       = json_decode( $merge_fields, true );
    $key_values   = array();

    $field_count = count( $fields );
  $body=array();
    for ( $i = 0; $i < $field_count; $i ++ ) {
      $key   = $fields[ $i ]['KEY'];
      $value = Automator()->parse->text( $fields[ $i ]['VALUE'], $recipe_id, $user_id, $args );
      $body[$key]=$value;
    }
    $body['api_token']=$api_token;
    $body['list_id']=$list_id;

    $url='https://api.mailketing.co.id/api/v1/addsubtolist';
    $args = array(
        'method' => 'POST',
        'timeout' => '10',
            'blocking' => false,
        'headers'  => array(
            'Content-type: application/x-www-form-urlencoded'
        ),
        'sslverify' => true,
        'body' => $body
    );
    $response = wp_remote_post( $url,$args);
    $response=wp_remote_retrieve_body($response);

            if ($response instanceof WP_Error) {
                /* translators: 1. Webhook URL */
                $error_message = sprintf(esc_attr__('An error was found in the webhook (%1$s) response.', 'uncanny-automator'), $url);
                Automator()->complete->action($user_id, $action_data, $recipe_id, $error_message);

                return;
            }

            Automator()->complete->action($user_id, $action_data, $recipe_id);
        }
    }

    public function get_fields() {

		$fields = array();

		// List of available campaigns
		$fields[] = array(
			'input_type'            => 'select',
			'option_code'           => 'list_id',
			/* translators: HTTP request method */
			'label'                 => esc_attr__( 'Campaign', 'uncanny-automator' ),
			'description'           => esc_attr__( 'Inline campaigns are not supported as they are always displayed.', 'uncanny-automator' ),
			'required'              => true,
			'supports_custom_value' => false,
			'options'               => $this->get_all_lists(),
		);
    $fields[] = array(
			'input_type'        => 'repeater',
			'option_code'       => 'MERGE_FIELDS',
			'label'             => esc_attr__( 'Body', 'uncanny-automator' ),
			'required'          => true,
			'fields'            => array(
				array(
					'input_type'      => 'text',
					'option_code'     => 'KEY',
					'label'           => esc_attr__( 'Key', 'uncanny-automator' ),
					'supports_tokens' => true,
					'required'        => true,
					'placeholder'     => __( 'first_name', 'uncanny-automator' ),
					'description'     => sprintf( '<i>%s</i>', esc_html__( 'Separate keys with / to build nested data.', 'uncanny-automator' ) ),
				),
				array(
					'input_type'      => 'text',
					'option_code'     => 'VALUE',
					'label'           => esc_attr__( 'Value', 'uncanny-automator' ),
					'supports_tokens' => true,
					'required'        => false,
				),
			),

			/* translators: Non-personal infinitive verb */
			'add_row_button'    => esc_attr__( 'Add pair', 'uncanny-automator' ),
			/* translators: Non-personal infinitive verb */
			'remove_row_button' => esc_attr__( 'Remove pair', 'uncanny-automator' ),
		);

		return $fields;

	}

    public function get_all_lists() {
   $option=array();
  $optionsx = get_option( "mailketingsmtp_options" );
  $api_token   = $optionsx['mailketingsmtp_api'];
  try {

  		$url='https://api.mailketing.co.id/API/getLists';
  		$response = wp_remote_get( $url, array(
  				'APIToken'    => $api_token,
  				'headers' => array(
  						'APIToken' => $api_token,
  				),
  		) );

  		$ua=wp_remote_retrieve_body($response);
  		$has = json_decode($ua,true);

  			if( ! empty( $has['response']['list'] ) || isset($has['response']['list'])) {
  				$lists=$has['response']['list'];
  				foreach( $lists as $list ) {
  					$options[$list['list_id']] = $list['list_name'];
  				}
  			}
  	} catch ( \Exception $e ) {
  		$options[] = array(
  			'value' => '',
  			'text'  => $e->getMessage(),
  		);
  	}

  		return  $options ;
  	}
}
