<?php
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;
/*
Plugin Name: Mailketing SMTP
Version: 3.1.7
Plugin URI: https://mailketing.digital
Author: Fadli Dzil Ikram
Author URI: https://regrow.id
Description: Make Your Wordpress Emails using Mailketing SMTP API.
Text Domain: mailketing-smtp
Domain Path: /languages
*/

defined('ABSPATH') or die('You\'re not supposed to be here.');
/**
 *
 *
 * @author Fadlidzilikram
 */
 /**
  * Subclass of PHPMailer to prevent Sending.
  *
  * This subclass of PHPMailer replaces the send() method
  * with a method that does not send.
  * This subclass is based on the WP Core MockPHPMailer
  * found in phpunit/includes/mock-mailer.php
  *
  * @since 0.8.0
  * @see PHPMailer
  */

if (!class_exists('Mailketing_SMTP')):
class Mailketing_SMTP {
	public $VERSION = '3.1.7';
	public $MAIN;
	public $PATH;
	public $BASE;
	public $OPTIONS;
	public $SLUG = "mailketingsmtp";
	private $DEFAULT_OPTIONS = array( 'mailketingsmtp_api' => '','list_id' => '','from_email_field' => '', 'from_name_field' => '', 'reply_to_email' => '', 'mailer' => 'smtp', 'smtp_settings' => array( 'host' => '', 'type_encryption' => 'tls', 'port' => 587, 'autentication' => 'yes', 'username' => '', 'password' => '' ) );

	/**
	 * The Mailketing SMTP constructor function
	 *
	 * @param   string   $file  The plugin file path
	 * @return  object          Returns all Mailketing SMTP public methods and properties.
	 */
	function __construct( $file ) {
		$this->MAIN = $file;
		$this->BASE = plugin_basename( $file );
		$this->PATH = str_replace( DIRECTORY_SEPARATOR, '/', dirname( $file ) );
		$this->OPTIONS = get_option( "{$this->SLUG}_options" );

		if ( !$this->OPTIONS ) {
			$this->OPTIONS = $this->DEFAULT_OPTIONS;
		}

		/**
		 * Add all hooks
		 */
		register_activation_hook( $file, array(
			 $this,
			'activate'
		) );
		register_deactivation_hook( $file, array(
			 $this,
			'uninstall'
		) );

    add_filter('wpcf7_editor_panels', function ($panels) {
        $panels['mailketing'] = array(
            'title' => 'Mailketing',
            'callback' => array($this, 'contact_form')
        );

        return $panels;
    });
    add_filter('wpcf7_contact_form_properties', array($this, 'get_properties'), 99, 2);
    add_action('wpcf7_mail_sent', array($this, 'contact_form_submit'), 99);
    add_filter( 'caldera_forms_get_form_processors',  array( $this, 'icfmk_register_processor' ) );

		if ( is_admin() ) {
			add_action( 'admin_menu', array(
				 $this,
				'admin_menu'
			) );
			add_action( 'wp_ajax_' . $this->SLUG, array(
				 $this,
				'ajax_actions'
			) );

			add_action( 'admin_enqueue_scripts', array(
				 $this,
				'admin_head'
			) );
			add_action( 'admin_notices', array(
				 $this,
				'admin_notice'
			) );

			add_filter( 'plugin_action_links', array(
				 $this,
				'action_links'
			), 10, 2 );
			add_filter( 'plugin_row_meta', array(
				 $this,
				'register_plugin_links'
			), 10, 2 );
		}


	}
	/**
	 * Activating handler.
	 * @return void
	 */
	public function activate() {
		/* install the default options */
		if ( !get_option( "{$this->SLUG}_options" ) ) {
			add_option( "{$this->SLUG}_options", $this->DEFAULT_OPTIONS, '', 'yes' );
		}
	}

	/**
	 * Uninstalling handler.
	 * @return void
	 */
	public function uninstall() {
		/* delete plugin options */
		delete_site_option( "{$this->SLUG}_options" );
		delete_site_option( "{$this->SLUG}_smtp_test_mail" );
		delete_option( "{$this->SLUG}_options" );
		delete_option( "{$this->SLUG}_smtp_test_mail" );

		//Clear fadliNotify
		//fadliNotify::clear_schedule_cron( __FILE__ );
	}

	/**
	 * Add menu and submenu.
	 * @return void
	 */
	public function admin_menu() {
		add_options_page( __( 'Mailketing SMTP', 'mailketing-smtp' ), __( 'Mailketing SMTP', 'mailketing-smtp' ), 'manage_options', "{$this->SLUG}_settings", array(
			 $this,
			'page_init'
		) );
	}

  public function icfmk_register_processor( $processors ) {
      $processors['cf_mailketing_integration'] = array(
      'name'              =>  __( 'Mailketing Integration', 'integrate-caldera-forms-mailketing' ),
      'description'       =>  __( 'Send Caldera Forms submission data to Mailketing using Mailketing REST API.', 'integrate-caldera-forms-mailketing' ),
      'pre_processor'		=>  array( $this, 'cf_mailketing_integration_processor' ),
      'template' 			=>  __DIR__ . '/inc/configcal.php'
    );
    return $processors;
  }

  function cf_mailketing_integration_processor( $config, $form, $process_id ) {
      if( !isset( $config['icfmk_mailketing_obj'] ) || empty( $config['icfmk_mailketing_obj'] ) ){
        return;
  }

    $mailketing_object = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_obj'] );
    $mailketing_first_name = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_first_name'] );
      $mailketing_last_name = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_last_name'] );
      $mailketing_email = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_email'] );
      $mailketing_company = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_company'] );
      $mailketing_title = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_title'] );
      $mailketing_mobile = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_mobile'] );
			$mailketing_city = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_city'] );
			$mailketing_country = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_country'] );
			$mailketing_state = Caldera_Forms::do_magic_tags( $config['icfmk_mailketing_state'] );

      $options = get_option( "mailketingsmtp_options" );
        $url='https://api.mailketing.co.id/api/v1/addsubtolist';
        $args = array(
            'method' => 'POST',
            'timeout' => '10',
                'blocking' => false,
            'headers'  => array(
                'Content-type: application/x-www-form-urlencoded'
            ),
            'sslverify' => true,
            'body' => array(
              'first_name'    => $mailketing_first_name,
              'last_name'    => $mailketing_last_name,
              'email'    => $mailketing_email,
              'company'    => $mailketing_company,
              'title'    => $mailketing_title,
              'mobile'    => $mailketing_mobile,
							'city'    => $mailketing_city,
							'country'    => $mailketing_country,
							'state'    => $mailketing_state,
              'api_token'    => $options['mailketingsmtp_api'],
              'list_id'	=> $mailketing_object
            )
        );
        $response = wp_remote_post( $url,$args);
        $response=wp_remote_retrieve_body($response);

  }


	/**
	 * Add action links on plugin page in to Plugin Name block
	 * @param  $links array() action links
	 * @param  $file  string  relative path to pugin "mailketing-smtp/mailketing-smtp.php"
	 * @return $links array() action links
	 */
	public function action_links( $links, $file ) {
		if ( $file == $this->BASE ) {
			$settings_link = '<a href="options-general.php?page=mailketingsmtp_settings">' . __( 'Settings', 'mailketing-smtp' ) . '</a>';
			array_unshift( $links, $settings_link );
		}
		return $links;
	}

	/**
	 * Add action links on plugin page in to Plugin Description block
	 * @param  $links array() action links
	 * @param  $file  string  relative path to pugin "mailketing-smtp/mailketing-smtp.php"
	 * @return $links array() action links
	 */
	public function register_plugin_links( $links, $file ) {
		if ( $file == $this->BASE ) {
			$links[] = '<a href="options-general.php?page=mailketingsmtp_settings">' . __( 'Settings', 'mailketing-smtp' ) . '</a>';
		}
		return $links;
	}

	/**
	 * Page contents initialize.
	 *
	 * @return  void
	 */
	public function page_init() {
		echo '<div class="wrap" id="mailketingsmtp-mail">';
		echo '<h2>' . __( "Pengaturan Mailketing SMTP", 'mailketing-smtp' ) . '</h2>';
		echo '<div><div id="post-body">';

		$display_add_options = $message = $error = $result = '';

		$options           = $this->OPTIONS;
		$smtp_test_default = array(
			'mailketingsmtp_to' => '',
			'mailketingsmtp_send_to' => 'custom',
			'mailketingsmtp_subject' => '',
			'mailketingsmtp_message' => ''
		);

		if ( $smtp_test_mail = get_option( "{$this->SLUG}_smtp_test_mail" ) ) {
			$smtp_test_mail = array_merge( $smtp_test_default, $smtp_test_mail );
		}
		else {
			$smtp_test_mail = $smtp_test_default;
		}
?>
		<div class="mailketingsmtp-green-box">
			<?php printf( __( 'Please Visit Mailketing Tutorial to Use this Plugin', 'mailketing-smtp' ) ); ?>
		</div>

		<div id="mailketingsmtp-settings-notice" class="mailketingsmtp-yellow-box" style="display:none">
			<strong><?php _e( "Notice:", 'mailketing-smtp' ); ?></strong> <?php _e( "Configuration Changed, dont forget to save modified setup", 'mailketing-smtp' ); ?>
		</div>

		<div class="mailketingsmtp-box">
			<div class="box-title"><h3><?php _e( 'Mailketing Configuration', 'mailketing-smtp' ); ?></h3></div>
			<div class="inside">

				<p><?php _e( "Please Open Mailketing Web, add domain, Create List, and generate token api before setup", 'mailketing-smtp' ); ?></p>


				<form id="mailketingsmtp_api_form" method="post" action="">
					<input type="hidden" name="mailketingsmtp_task" value="cektoken">
					<table class="form-table">
						<tr>
							<th><?php _e( 'MailKeting API Token', 'mailketing-smtp' ); ?></th>
							<td colspan="3">

								<input type="text" name="mailketingsmtp_api" id="mailketingsmtp_api" value="<?php echo esc_attr( $options['mailketingsmtp_api'] ); ?>"/><br />
								<p class="description"><?php _e( "Fill with  API Token from MailKeting Mailketing, login mailketing, Integration > generate token", 'mailketing-smtp' ); ?></p>
							</td>
						</tr>
					</table>
					<p class="submit">
						<input type="submit" id="settings-form-submit" class="button-primary" value="<?php _e( 'Connect', 'mailketing-smtp' ); ?>" />
						<input type="hidden" name="mailketingsmtp_api_submit" value="submit" />
						<?php wp_nonce_field( plugin_basename( __FILE__ ), 'mailketingsmtp_nonce_name' ); ?>
						<span class="circle-loader"><span class="checkmark draw"></span></span>
						<span class="mailketingsmtp_ajax_message">Error</span>
					</p>
				</form>
      </div><!-- end of inside -->
    </div><!-- end of postbox -->

    <div class="mailketingsmtp-box">
      <div class="box-title"><h3><?php _e( 'Default Configuration', 'mailketing-smtp' ); ?></h3></div>
      <div class="inside">


                <p><?php _e( "Every Email from wordpress will be changed ( from name and from email ) with this configuration", 'mailketing-smtp' ); ?></p>


        <form autocomplete="off" id="mailketingsmtp_settings_wc" method="post" action="">
          <input type="hidden" name="mailketingsmtp_task" value="settings">
          <table class="form-table">
            <tr valign="top">
              <th scope="row"><?php _e( "From Name", 'mailketing-smtp' ); ?></th>
              <td>
                <input type="text" name="mailketingsmtp_from_name" id="mailketingsmtp_from_name" value="<?php echo esc_attr( $options['from_name_field'] ); ?>">
                <p class="description"><?php _e( "Input From Name", 'mailketing-smtp' ); ?></p>
              </td>
            </tr>
            <tr valign="top">
              <th scope="row"><?php _e( "From Email", 'mailketing-smtp' ); ?></th>
              <td>
                <select name="mailketingsmtp_from_email" id="mailketingsmtp_from_email">
                  <option value="<?php echo esc_attr( $options['from_email_field'] ); ?>"><?php echo esc_attr( $options['from_email_field'] ); ?></option>
                </select>
                <p class="description"><?php _e( "please choose from email", 'mailketing-smtp' ); ?></p>
              </td>
            </tr>
            <tr>

                          <th scope="row"><?php _e( "Auto Capture Register WP -> List Mailketing", 'mailketing-smtp' ); ?></th>
                          <td>
                            <select name="mailketingsmtp_list" id="mailketingsmtp_list">
                              <option value="<?php echo esc_attr( $options['list_id'] ); ?>"><?php echo esc_attr( $options['list_id'] ); ?></option>
                            </select>
                            <p class="description"><?php _e( "Please choose lists, every new register member on your wordpress will be save in this list", 'mailketing-smtp' ); ?></p>
                              <input type="hidden" name="mailketingsmtp_api2" id="mailketingsmtp_api2" value="<?php echo esc_attr( $options['mailketingsmtp_api'] ); ?>">
                              <input type="hidden" name="mailketingsmtp_smtp_username" id="mailketingsmtp_smtp_username" value="<?php echo esc_attr( $options['smtp_settings']['username'] ); ?>">
                              <input type="hidden" name="mailketingsmtp_smtp_password" id="mailketingsmtp_smtp_password" value="<?php echo esc_attr($options['smtp_settings']['password'] ); ?>">
                              <input type="hidden" name="mailketingsmtp_smtp_host" id="mailketingsmtp_smtp_host" value="<?php echo esc_attr( $options['smtp_settings']['host'] ); ?>">
                          </td>
                        </tr>

			  <?php

		if(function_exists( 'crisp_hook_head' )) {
			if(isset($options['crisp_id'] )){
				$cid=$options['crisp_id'];
			}else{
				$cid="";
			}

			  ?>
			  <tr>

                          <th scope="row"><?php _e( "Auto Capture Crisp Chat -> Mailketing List", 'mailketing-smtp' ); ?></th>
                          <td>
                            <select name="mailketingcrisp_list" id="mailketingcrisp_list">
                              <option value="<?php echo esc_attr( $cid ); ?>"><?php echo esc_attr( $cid ); ?></option>
                            </select>
                            <p class="description"><?php _e( "Please Choose List to AutoCapture When Crisp Email Added", 'mailketing-smtp' ); ?></p>
                          </td>
                        </tr>
			  <?php

		}
    	if ( in_array('woocommerce/woocommerce.php',apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
?>
<tr>

                  <th scope="row"><?php _e( "Capture Order WooCommerce", 'mailketing-smtp' ); ?></th>
                  <td>
                    <select name="mailketingwo_order" id="mailketingwo_order">
                      <option value="<?php echo esc_attr( $options['wo_order'] ); ?>"><?php echo esc_attr( $options['wo_order'] ); ?></option>
                    </select>
                    <p class="description"><?php _e( "Please Choose List to AutoCapture When User Order", 'mailketing-smtp' ); ?></p>
                  </td>
                </tr>

                <tr>

                                  <th scope="row"><?php _e( "Capture Complete Order WooCommerce", 'mailketing-smtp' ); ?></th>
                                  <td>
                                    <select name="mailketingwo_complete" id="mailketingwo_complete">
                                      <option value="<?php echo esc_attr( $options['wo_complete'] ); ?>"><?php echo esc_attr( $options['wo_complete'] ); ?></option>
                                    </select>
                                    <p class="description"><?php _e( "Please Choose List to AutoCapture When Order Completed", 'mailketing-smtp' ); ?></p>
                                  </td>
                                </tr>


<?php

      }

			  ?>

          </table>

          <p class="submit">
            <input type="submit" id="settings-form-submit" class="button-primary" value="<?php _e( 'Save Setting', 'mailketing-smtp' ); ?>" />
            <input type="hidden" name="mailketingsmtp_form_submit" value="submit" />
            <?php wp_nonce_field( plugin_basename( __FILE__ ), 'mailketingsmtp_nonce_name' ); ?>
            <span class="circle-loader"><span class="checkmark draw"></span></span>
            <span class="mailketingsmtp_ajax_message">Error</span>
          </p>
        </form>
      </div><!-- end of inside -->
    </div><!-- end of postbox -->

		<div class="mailketingsmtp-box">
			<div class="box-title"><h3><?php _e( 'TEST Send Email', 'mailketing-smtp' ); ?></h3></div>
			<div class="inside">
				<p><?php _e( 'You Can Test is Smtp Works or Not', 'mailketing-smtp' ); ?></p>

				<form id="mailketingsmtp_testing_form" method="post" action="">
					<input type="hidden" name="mailketingsmtp_task" value="test_mail">
					<table class="form-table">
						<tr valign="top">
							<th scope="row"><?php _e( "To", 'mailketing-smtp' ); ?>:</th>
							<td>

								<div id="send_to">
									<input type="text" name="mailketingsmtp_to" value="<?php echo $smtp_test_mail['mailketingsmtp_to']; ?>" /><br />
									<p class="description"><?php _e( "Recipient Email", 'mailketing-smtp' ); ?></p>
								</div>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php _e( "Subject", 'mailketing-smtp' ); ?>:</th>
							<td>
								<input type="text" name="mailketingsmtp_subject" value="<?php echo esc_html( $smtp_test_mail['mailketingsmtp_subject'] ); ?>" /><br />
								<p class="description"><?php _e( "Email Subject", 'mailketing-smtp' ); ?><br /><?php _e( "Variable values are:", 'mailketing-smtp' ); ?> <code>%first_name%</code>, <code>%last_name%</code> and <code>%email%</code>.</p>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php _e( "Message", 'mailketing-smtp' ); ?>:</th>
							<td>
								<textarea name="mailketingsmtp_message" id="mailketingsmtp_message" rows="8"><?php echo $smtp_test_mail['mailketingsmtp_message']; ?></textarea><br />
								<p class="description"><?php _e( "Message", 'mailketing-smtp' ); ?><br /><?php _e( "Variable values are:", 'mailketing-smtp' ); ?> <code>%first_name%</code>, <code>%last_name%</code> and <code>%email%</code>.</p>
							</td>
						</tr>
					</table>
					<p class="submit">
						<input type="submit" id="settings-form-submit" class="button-primary" value="<?php _e( 'SEND TEST', 'mailketing-smtp' ); ?>" />
						<input type="hidden" name="mailketingsmtp_test_submit" value="submit" />
						<?php wp_nonce_field( plugin_basename( __FILE__ ), 'mailketingsmtp_nonce_name' ); ?>
						<span class="circle-loader"><span class="checkmark draw"></span></span>
						<span class="mailketingsmtp_ajax_message">Error</span>
					</p>
				</form>
			</div><!-- end of inside -->
		</div><!-- end of postbox -->

		<?php
		echo '</div></div>'; //<!-- end of #poststuff and #post-body -->
		echo '</div>'; //<!--  end of .wrap #mailketingsmtp-mail .mailketingsmtp-mail -->
	}

	/**
	 * Function to add plugin scripts
	 * @return void
	 */
	public function admin_head() {
		if ( isset( $_REQUEST['page'] ) && 'mailketingsmtp_settings' == $_REQUEST['page'] ) {
			wp_enqueue_style( 'mailketingsmtp_stylesheet', plugins_url( 'css/style.css', __FILE__ ), null, $this->VERSION );
			wp_enqueue_script( 'mailketingsmtp_script', plugins_url( 'js/script.js', __FILE__ ), array(
				 'jquery'
			), $this->VERSION );
		}
	}

	public function admin_notice() {
		if ( !mailketingsmtp_is_ok() ) {
			$settings_url = admin_url() . 'options-general.php?page=mailketingsmtp_settings';
?>
			<div class="notice notice-error">
				<p><?php printf( __( 'Please Configure Mailketing Smtp first on <a href="%s">settings menu</a>', 'mailketing-smtp' ), esc_url( $settings_url ) ); ?></p>
			</div>
			<?php
		}
	}

  // integration with contact form 7


  public function contact_form($post)
  {
      echo '<h2>Mailketing Integration</h2>';
      $form_value = $post->prop('mailketing');
      $has = get_mailketing_list();
      $lists=$has['response']['list'];
      //print_r($lists);
          ?>
          <fieldset>
              <table class="form-table">
                  <tbody>
                  <tr>
                      <th scope="row">
                          <label
                              for="wpcf7-mailketing[list]">Select Mailketing List</label>
                      </th>
                      <td>
                          <select name="wpcf7-mailketing[list]">
                              <?php
                              foreach ($lists as $list) {

                                  ?>
                                  <option
                                      value="<?php echo $list['list_id']; ?>"<?php echo (isset($form_value['list']) && $form_value['list'] == $list['list_id']) ? ' selected' : ''; ?>><?php echo $list['list_name']; ?></option>
                                  <?php
                              }
                              ?>
                          </select>
                      </td>
                  </tr>

                  </tbody>
              </table>
          </fieldset>
          <?php
  }

  public function get_properties($properties, $obj)
  {
      if ($_POST) {
          if (isset($_POST['wpcf7-mailketing'])) {
              $properties['mailketing'] = array();
              foreach ($_POST['wpcf7-mailketing'] as $key => $value) {
                  $properties['mailketing'][$key] = intval($value);
              }
          }
      } else {
          $post_meta = get_post_meta($obj->id(), '_mailketing', true);
          if (!empty($post_meta)) {
              $properties['mailketing'] = $post_meta;
          }
      }

      return $properties;
  }

  public function contact_form_submit($obj)
  {
      // if form is synced
      $prop = get_post_meta($obj->id(), '_mailketing', true);
      // send to KE
      $is_email_field_exist = false;
      foreach ($_POST as $key => $value) {
          if (strpos($key, 'email') !== false) {
              $is_email_field_exist = true;
              break;
          }
      }

      if ($is_email_field_exist) {
          $data = array(
              'lists' => array($prop['list'])
          );
          foreach ($_POST as $key => $value) {
              if (strpos($key, '_wpcf7') !== false) {
                  continue;
              }
              if (strpos($key, 'first_name') !== false) {
                  $data['first_name'] = $value;
              }else if (strpos($key, 'email') !== false) {
                  $data['email'] = $value;
              }else if (strpos($key, 'last_name') !== false) {
                  $data['last_name'] = $value;
              }else if (strpos($key, 'name') !== false && !isset($data['first_name'])) {
                  $data['first_name'] = $value;
              }else if (strpos($key, 'phone') !== false) {
                  $data['phone'] = $value;
              }else if (strpos($key, 'mobile') !== false) {
                  $data['mobile'] = $value;
              }else if (strpos($key, 'city') !== false) {
                  $data['city'] = $value;
              }else if (strpos($key, 'state') !== false) {
                  $data['state'] = $value;
              }else if (strpos($key, 'country') !== false) {
                  $data['country'] = $value;
              }else if (strpos($key, 'company') !== false) {
                  $data['company'] = $value;
              }else if (strpos($key, 'title') !== false) {
                  $data['title'] = $value;
              }
          }
          $options = get_option( "mailketingsmtp_options" );
            $url='https://api.mailketing.co.id/api/v1/addsubtolist';
            $args = array(
                'method' => 'POST',
                'timeout' => '10',
                    'blocking' => false,
                'headers'  => array(
                    'Content-type: application/x-www-form-urlencoded'
                ),
                'sslverify' => true,
                'body' => array(
                  'first_name'    => $data['first_name'],
									'last_name'    => $data['last_name'],
									'city'    => $data['city'],
									'country'    => $data['country'],
									'state'    => $data['state'],
									'company'    => $data['company'],
                  'email'    => $data['email'],
                  'phone'    => $data['phone'],
									'mobile'    => $data['mobile'],
									'title'    => $data['title'],
                  'api_token'    => $options['mailketingsmtp_api'],
                  'list_id'	=> $prop['list']
                )
            );
            $response = wp_remote_post( $url,$args);
            $response=wp_remote_retrieve_body($response);
      }
  }

	/**
	 * Function to test mail sending
	 * @return text or errors
	 */
	public function test_mail( $to_email, $subject, $message ) {
		return wp_mail($to_email, $subject, $message);
	}

	/**
	 * Function to get user info
	 * @return text or errors
	 */
	public function user_info( $user_id = 1 ) {
		$user      = get_userdata( $user_id );
		$user_meta = get_user_meta( $user_id );

		return array(
			"first_name" => implode( '', $user_meta['first_name'] ),
			"last_name" => implode( '', $user_meta['last_name'] ),
			"email" => $user->user_email
		);
	}

	/**
	 * Function to get emails list
	 * @return text or errors
	 */
	public function get_emails_list( $type = 'users' ) {
		global $wpdb;
		$list = array();

		if ( $type === 'users' ) {
			$users = $wpdb->get_results("SELECT ID FROM $wpdb->users GROUP BY user_email");

			foreach ( $users as $user ) {
				$list[] = $this->user_info( $user->ID );
			}
		}
		else {
			$comments = $wpdb->get_results("SELECT comment_author_email, comment_author, user_id FROM $wpdb->comments WHERE comment_author_email != '' AND comment_approved<>'spam' GROUP BY comment_author_email");

			foreach ( $comments as $comment ) {
				if ( $comment->user_id ) {
					$list[] = $this->user_info( $comment->user_id );
				} else {
					$parts = explode( ' ', $comment->comment_author );
					$first_name = array_shift( $parts );
					$last_name = array_pop( $parts );
					$list[] = array(
						"first_name" => $first_name,
						"last_name" => $last_name,
						"email" => $comment->comment_author_email
					);
				}
			}
		}

		return $list;
	}

	/**
	 * Register ajax actions.
	 *
	 * @return  {void}
	 */
	public function ajax_actions() {


		$result = array();
		$p      = @stripslashes_deep( $_POST );

		$task = @$p['mailketingsmtp_task'];

		unset( $p['mailketingsmtp_task'] );

		// check for rights
		if ( !current_user_can( "manage_options" ) || !$task || !check_ajax_referer( plugin_basename( __FILE__ ), 'mailketingsmtp_nonce_name', false ) ) {
			$result = array(
				 'status' => 403,
				'message' => __( 'Anda Tidak Diizinkan Mengubah Konfigurasi Mailketing SMTP', 'mailketing-smtp' )
			);
		} else {
			$options = $this->OPTIONS;
			$message = '';
			$error   = array();

			if ( $task == "settings" ) {
				/* Update settings */
				$options['from_name_field'] = isset( $p['mailketingsmtp_from_name'] ) ? sanitize_text_field( wp_unslash( $p['mailketingsmtp_from_name'] ) ) : $this->DEFAULT_OPTIONS['from_name_field'];

				if ( isset( $p['mailketingsmtp_from_email'] ) && !empty( $p['mailketingsmtp_from_email'] ) ) {
					//if ( is_email( $p['mailketingsmtp_from_email'] ) ) {
						$options['from_email_field'] = sanitize_email( $p['mailketingsmtp_from_email'] );
					//} else {
						//$error[] = "<li>" . sprintf( __( "Please enter a valid email address in the '%s' field.", 'mailketing-smtp' ), __( "From Email", 'mailketing-smtp' ) ) . "</li>";
					//}
				} else {
					$error[] = "<li>" . sprintf( __( "Please enter a valid email address in the '%s' field.", 'mailketing-smtp' ), __( "From Email", 'mailketing-smtp' ) ) . "</li>";
				}
				$options['reply_to_email']=$options['from_email_field'];
				$options['mailer'] = 'smtp';

				/* Check value from "SMTP Host" option */
				if ( isset( $p['mailketingsmtp_smtp_host'] ) ) {
					if ( empty( $p['mailketingsmtp_smtp_host'] ) ) {
						$options['smtp_settings']['host'] = '';
						$error[]                          = "<li>" . __( "Please enter a valid host in the 'SMTP Host' field.", 'mailketing-smtp' ) . "</li>";
					} else {
						$options['smtp_settings']['host'] = sanitize_text_field( $p['mailketingsmtp_smtp_host'] );
					}
				}
				$options['smtp_settings']['type_encryption'] ='tls';
				$options['smtp_settings']['autentication']   = 'yes';

				$options['mailketingsmtp_api'] = $p['mailketingsmtp_api2'];
				$options['list_id'] = sanitize_text_field( $p['mailketingsmtp_list'] );
				$options['crisp_id'] = sanitize_text_field( $p['mailketingcrisp_list'] );
        $options['wo_order'] = sanitize_text_field( $p['mailketingwo_order'] );
        $options['wo_complete'] = sanitize_text_field( $p['mailketingwo_complete'] );
				$options['smtp_settings']['username'] = sanitize_text_field( $p['mailketingsmtp_smtp_username'] );
				$smtp_password                        = sanitize_text_field( $p['mailketingsmtp_smtp_password'] );
				$options['smtp_settings']['password'] = $smtp_password ;

				/* Check value from "SMTP port" option */
				$options['smtp_settings']['port']='587';


				/* Update settings in the database */
				if ( empty( $error ) ) {
					update_option( "{$this->SLUG}_options", $options );
					$message = __( "Settings saved.", 'mailketing-smtp' );
				} else {
					$message = __( "Settings are not saved.", 'mailketing-smtp' );
				}

				$result = array(
					 'status' => empty( $error ) ? 200 : 403,
					'error' => $error,
					'message' => $message
				);
			}else if( $task == "cektoken"){
				$url='https://api.mailketing.co.id/API/getLists';
			  $response = wp_remote_get( $url, array(
			      'APIToken'    => $p['mailketingsmtp_api'],
			      'headers' => array(
			          'APIToken' => $p['mailketingsmtp_api'],
			      ),
			  ) );
				$ua=wp_remote_retrieve_body($response);
			  wp_die($ua);
			}

			else if ( $task == "test_mail" ) {
				$smtp_test_mail = get_option( "{$this->SLUG}_smtp_test_mail" );
				if ( empty( $smtp_test_mail ) ) {
					$smtp_test_mail = array(
						'mailketingsmtp_to' => '',
						'mailketingsmtp_send_to' => '',
						'mailketingsmtp_subject' => '',
						'mailketingsmtp_message' => ''
					);
				}

				$mailketingsmtp_to = '';
				$mailketingsmtp_send_to = isset( $p['mailketingsmtp_send_to'] ) ? sanitize_text_field( $p['mailketingsmtp_send_to'] ) : 'custom';
				if ( isset( $p['mailketingsmtp_to'] ) && $mailketingsmtp_send_to === 'custom' ) {

						$mailketingsmtp_to = $p['mailketingsmtp_to'];

				}
				$mailketingsmtp_subject = isset( $p['mailketingsmtp_subject'] ) ? sanitize_text_field( $p['mailketingsmtp_subject'] ) : '';
				$mailketingsmtp_message = $p['mailketingsmtp_message'];

				//Save the test mail details so it doesn't need to be filled in everytime.
				$smtp_test_mail['mailketingsmtp_to']      = $mailketingsmtp_to;
				$smtp_test_mail['mailketingsmtp_send_to'] = $mailketingsmtp_send_to;
				$smtp_test_mail['mailketingsmtp_subject'] = $mailketingsmtp_subject;
				$smtp_test_mail['mailketingsmtp_message'] = $mailketingsmtp_message;
				update_option( "{$this->SLUG}_smtp_test_mail", $smtp_test_mail );

				if ( empty( $error ) ) {
						$result = $this->test_mail( $mailketingsmtp_to, $mailketingsmtp_subject, $mailketingsmtp_message );

					if ( is_bool( $result ) && $result ) {
						$message = __( 'Test mail was sent', 'mailketing-smtp' );
					} else {
						$error[] = "<li>" . $result . "</li>";
					}
				}

				if ( !empty( $error ) )
					$message = __( 'Test mail was not sent', 'mailketing-smtp' );

				$result = array(
					 'status' => empty( $error ) ? 200 : 403,
					'error' => $error,
					'message' => $message
				);
			}

			else
				$result = array(
					 'status' => 400,
					'message' => __( "Bad Request", 'mailketing-smtp' )
				);
		}

		wp_die( json_encode( $result ) );
	}
}

// Run Mailketing_SMTP
define( 'EDD_mailketing_PATH', dirname( __FILE__ ) );

if( !class_exists( 'EDD_Newsletter' ) ) {
	include( EDD_mailketing_PATH . '/inc/class-edd-newsletter.php' );
}

if( ! class_exists( 'Sejoli_Mailketing' ) ) {
	include( EDD_mailketing_PATH . '/inc/class-sejoli-autoresponder.php' );
}

if( ! class_exists( 'EDD_mailketing' ) ) {
	include( EDD_mailketing_PATH . '/inc/class-edd-mailketing.php' );
}

if( ! class_exists( 'Uncanny_Mailketing' ) ) {
	include( EDD_mailketing_PATH . '/inc/uncanny-mailketing.php' );
}

$edd_mailketing = new EDD_mailketing( 'mailketing', 'mailketing' );
$sejoli_mailketing_cuy= new Sejoli_Mailketing();
$Mailketing_SMTP = new Mailketing_SMTP( __FILE__ );
new Uncanny_Mailketing();

//add_action( 'plugins_loaded', 'replaceasd' );
//add_filter( 'wp_mail', 'wp_mail' );
add_action( 'phpmailer_init', 'mailketingsmtp_init_smtp' );


		if(function_exists( 'crisp_hook_head' )) {
function mailketing_crisp() {
	$options = get_option( "mailketingsmtp_options" );
	if(isset($options['crisp_id'])){
	$output="<script type='text/javascript' charset='UTF-8' src='https://api.mailketing.co.id/js/mailketingcrisp.js'>
		</script>
		<script type='text/javascript'>
			var list_id = '".$options['crisp_id']."';
		</script>";
			echo $output;
		}
}

add_action('wp_head', 'mailketing_crisp');
}
add_filter( 'wp_pre_insert_user_data', 'mailketing_user_register', 10, 3 );
function mailketing_user_register( $data, $update, $id ) {

$options = get_option( "mailketingsmtp_options" );
if(isset($options['list_id']) && !empty($options['list_id'])){
  $url='https://api.mailketing.co.id/api/v1/addsubtolist';
	$mobilex="";
	if(isset($data['user_phone'])){
		$mobilex=$data['user_phone'];
	}elseif(isset($data['user_mobile'])){
		$mobilex=$data['user_mobile'];
	}
  $args = array(
      'method' => 'POST',
      'timeout' => '10',
          'blocking' => false,
      'headers'  => array(
          'Content-type: application/x-www-form-urlencoded'
      ),
      'sslverify' => true,
      'body' => array(
        'first_name'    => $data['display_name'] ?? "",
				'last_name'    => $data['last_name'] ?? "",
				'mobile'    => $mobilex ?? "",
        'email'    => $data['user_email'],
        'api_token'    => $options['mailketingsmtp_api'],
        'list_id'	=> $options['list_id']
      )
  );
  $response = wp_remote_post( $url,$args);
  $ua=wp_remote_retrieve_body($response);
}
return $data;
}

//Load Translation files
if( !function_exists( 'mailketingsmtp_i18n' )) {
	function mailketingsmtp_i18n() {
		$path = path_join( dirname( plugin_basename( __FILE__ ) ), 'languages/' );
		load_plugin_textdomain( 'mailketing-smtp', false, $path );
	}
}
function get_mailketing_list()
{
    $options = get_option( "mailketingsmtp_options" );
    $url='https://api.mailketing.co.id/API/getLists';
    $response = wp_remote_get( $url, array(
        'APIToken'    => $options['mailketingsmtp_api'],
        'headers' => array(
            'APIToken' => $options['mailketingsmtp_api'],
        ),
    ) );

    $ua=wp_remote_retrieve_body($response);
    return json_decode($ua,true);
}
if( !function_exists( 'wp_mail' )) {
  function wp_mail( $to, $subject, $message, $headers = '', $attachments = array()) {
  	extract( apply_filters( 'wp_mail', compact( 'to', 'subject', 'message', 'headers', 'attachments' ) ) );
    $options = get_option( "mailketingsmtp_options" );
    if ( !mailketingsmtp_is_ok() ) {
      return "Please Save Setting First";
    }
    if ( !is_array( $to ) ) {
      $to = explode( ',', preg_replace( '/\s+/', '', $to ) ); // strip all whitespace.
    }
    if (! is_array( $attachments ) ) {
          $attachments = explode( "\n", str_replace( "\r\n", "\n", $attachments ) );
      }
  $attach1="";
  $attach2="";
  $attach3="";
  $kj=0;
      if ( ! empty( $attachments ) ) {
          foreach ( $attachments as $attachment ) {
            $kj++;
              if($kj==1){
                $attach1 =str_replace(ABSPATH,get_home_url().'/',$attachment);
              }elseif($kj==2){
                $attach2 =str_replace(ABSPATH,get_home_url().'/',$attachment);
              }if($kj==3){
                $attach3 =str_replace(ABSPATH,get_home_url().'/',$attachment);
              }
          }
      }

      $url='https://api.mailketing.co.id/wpmail';
      $from_name    = !empty( $options['from_name_field'] ) ? $options['from_name_field'] : $current_user->display_name;
      $from_email   = !empty( $options['from_email_field'] ) ? $options['from_email_field'] : $current_user->user_email;

    $processed_to = "";
    foreach ( $to as $email ) {
      if ( is_array( $email ) ) {
        $processed_to = $email[0];
      } else {
        $processed_to=$email;
      }
      $tox = $processed_to;
      $args = array(
          'method' => 'POST',
          'timeout' => '10',
              'blocking' => false,
          'headers'  => array(
              'Content-type: application/x-www-form-urlencoded'
          ),
          'sslverify' => true,
          'body' => array(
            'charset'    => get_bloginfo( 'charset' ),
            'from_name'    => $from_name,
            'from_email'    => $from_email,
            'host'    => $options['smtp_settings']['host'],
            'username'    => $options['smtp_settings']['username'],
            'password'    => $options['smtp_settings']['password'],
            'subject'    => $subject,
            'to_email'    => $tox,
            'attach1'    => $attach1,
            'attach2'    => $attach2,
            'attach3'    => $attach3,
            'message'    => $message
          )
      );
      $response = wp_remote_post( $url,$args);
    }
    $ua=wp_remote_retrieve_body($response);
    if($ua == ''){
      return true;
    }else{
      return $processed_to;
    }
  }
}

if ( in_array('woocommerce/woocommerce.php',apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
add_action('woocommerce_order_status_changed', 'mailketingxwo_order',99,3);
function mailketingxwo_order($order_id, $old_status, $new_status) {
  $options = get_option( "mailketingsmtp_options" );
  $first_name = get_post_meta($order_id, '_billing_first_name', true);
  $last_name= get_post_meta($order_id, '_billing_last_name', true);
  $email = get_post_meta($order_id, '_billing_email', true);
	$mobile = get_post_meta($order_id, '_billing_phone', true);
  if($new_status == "completed"){
      $list_id=$options['wo_complete'];
  }else{
      $list_id=$options['wo_order'];
  }

  $url='https://api.mailketing.co.id/api/v1/addsubtolist';
  $args = array(
      'method' => 'POST',
      'timeout' => '10',
          'blocking' => false,
      'headers'  => array(
          'Content-type: application/x-www-form-urlencoded'
      ),
      'sslverify' => true,
      'body' => array(
        'first_name'    => $first_name,
        'last_name'    => $last_name,
        'email'    => $email,
				'mobile'    => $mobile,
        'api_token'    => $options['mailketingsmtp_api'],
        'list_id'	=> $list_id
      )
  );
  $response = wp_remote_post( $url,$args);
  $ua=wp_remote_retrieve_body($response);

}
}

	function mailketingsmtp_init_smtp( $phpmailer ) {
		$options = get_option( "mailketingsmtp_options" );
		if ( !mailketingsmtp_is_ok() ) {
			return $options;
		}
		$phpmailer->isSMTP();
		$from_email = trim( $options['from_email_field'] );
		$from_name = trim( $options['from_name_field'] );
		$phpmailer->From = $from_email;
		$phpmailer->FromName = $from_name;
	$phpmailer->SetFrom( $phpmailer->From, $phpmailer->FromName );
	$phpmailer->addCustomHeader('X-SMTP-BY', "Mailketing SMTP (https://mailketing.co.id)");
		$phpmailer->SMTPSecure = 'tls';
		$domain = substr($from_email, strpos($from_email, '@') + 1);
		$uniq_id = md5(uniqid(time()));
        //$mail->ReturnPath = $options['list_id'];
		/* Set the other options */
		$phpmailer->Host        = 'smtp.mailketing.id';
		$phpmailer->Port        = '587';
		$phpmailer->SMTPOptions = array(
			 'ssl' => array(
				 'verify_peer' => false,
				'verify_peer_name' => false,
				'allow_self_signed' => true
			)
		);
		$phpmailer->SMTPAuth = true;
		$phpmailer->Username = $options['smtp_settings']['username'];
		$phpmailer->Password = $options['smtp_settings']['password'];
		$phpmailer->SMTPAutoTLS = false;
	}


if( !function_exists( 'mailketingsmtp_is_ok' )) {
	function mailketingsmtp_is_ok() {
		$options = get_option( "mailketingsmtp_options" );
		$is_ok   = true;
		if ( !isset( $options['smtp_settings']['host'] ) || empty( $options['smtp_settings']['host'] ) ) {
			$is_ok = false;
		} else if ( !isset( $options['smtp_settings']['port'] ) || empty( $options['smtp_settings']['port'] ) ) {
			$is_ok = false;
		} else if ( isset( $options['smtp_settings']['autentication'] ) && $options['smtp_settings']['autentication'] == "yes" ) {
			if ( !isset( $options['smtp_settings']['username'] ) || empty( $options['smtp_settings']['username'] ) ) {
				$is_ok = false;
			} else if ( !isset( $options['smtp_settings']['password'] ) || empty( $options['smtp_settings']['password'] ) ) {
				$is_ok = false;
			}
		}

		return $is_ok;
	}
}
require plugin_dir_path(__FILE__).'update-checker/plugin-update-checker.php';
$MyUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://api.mailketing.co.id/wordpress/plugin/index.php?action=get_metadata&slug=mailketing-smtp', //Metadata URL.
	__FILE__, //Full path to the main plugin file.
	'mailketing-smtp' //Plugin slug. Usually it's the same as the name of the directory.
);
endif;
